@@ -25,7 +25,7 @@ if sys.version_info[0] < 3:
 else:
     from ipaddress import IPv4Network, IPv6Network, IPv4Address, IPv6Address
 """ ccp_util.py - Parse, Query, Build, and Modify IOS-style configurations
-     Copyright (C) 2014-2015, 2018-2020 David Michael Pennington
+     Copyright (C) 2014-2015, 2018-2021 David Michael Pennington
 
      This program is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -1062,7 +1062,20 @@ class IPv6Obj(object):
 
 
 class L4Object(object):
-    """Object for Transport-layer protocols; the object ensures that logical operators (such as le, gt, eq, and ne) are parsed correctly, as well as mapping service names to port numbers"""
+    """Object for Transport-layer protocols; the object ensures that logical operators (such as le, gt, eq, and ne) are parsed correctly, as well as mapping service names to port numbers
+    
+    Examples
+    --------
+    >>> from ciscoconfparse.ccp_util import L4Object
+    >>> obj = L4Object(protocol="tcp", port_spec="range ssh smtp", syntax="asa")
+    >>> obj
+    <L4Object tcp ports: 22-25>
+    >>> obj.protocol
+    'tcp'
+    >>> 25 in obj.port_list
+    True
+    >>>
+    """
 
     def __init__(self, protocol="", port_spec="", syntax=""):
         self.protocol = protocol
@@ -1086,29 +1099,39 @@ class L4Object(object):
         else:
             raise NotImplementedError("This syntax is unknown: '{0}'".format(syntax))
 
-        if "eq " in port_spec:
-            port_str = re.split("\s+", port_spec)[-1]
-            self.port_list = [int(ports.get(port_str, port_str))]
-        elif re.search(r"^\S+$", port_spec):
+        if "eq " in port_spec.strip():
+            port_tmp = re.split("\s+", port_spec)[-1].strip()
+            eq_port = int(ports.get(port_tmp, port_tmp))
+            assert 1 <= eq_port <= 65535
+            self.port_list = [eq_port]
+        elif re.search(r"^\S+$", port_spec.strip()):
             # Technically, 'eq ' is optional...
-            self.port_list = [int(ports.get(port_spec, port_spec))]
-        elif "range " in port_spec:
+            eq_port = int(ports.get(port_spec.strip(), port_spec.strip()))
+            assert 1 <= eq_port <= 65535
+            self.port_list = [eq_port]
+        elif "range " in port_spec.strip():
             port_tmp = re.split("\s+", port_spec)[1:]
-            self.port_list = range(
-                int(ports.get(port_tmp[0], port_tmp[0])),
-                int(ports.get(port_tmp[1], port_tmp[1])) + 1,
-            )
-        elif "lt " in port_spec:
+            low_port = int(ports.get(port_tmp[0], port_tmp[0]))
+            high_port = int(ports.get(port_tmp[1], port_tmp[1]))
+            assert low_port <= high_port
+            self.port_list = sorted(range(low_port, high_port+1))
+        elif "lt " in port_spec.strip():
+            port_tmp = re.split("\s+", port_spec)[-1]
+            high_port = int(ports.get(port_tmp, port_tmp))
+            assert 65536 >= high_port >= 2
+            self.port_list = sorted(range(1, high_port))
+        elif "gt " in port_spec.strip():
+            port_tmp = re.split("\s+", port_spec)[-1]
+            low_port = int(ports.get(port_tmp, port_tmp))
+            assert 0 < low_port < 65535
+            self.port_list = sorted(range(low_port+1, 65536))
+        elif "neq " in port_spec.strip():
             port_str = re.split("\s+", port_spec)[-1]
-            self.port_list = range(1, int(ports.get(port_str, port_str)))
-        elif "gt " in port_spec:
-            port_str = re.split("\s+", port_spec)[-1]
-            self.port_list = range(int(ports.get(port_str, port_str)) + 1, 65535)
-        elif "neq " in port_spec:
-            port_str = re.split("\s+", port_spec)[-1]
-            tmp = set(range(1, 65535))
+            tmp = set(range(1, 65536))
             tmp.remove(int(port_str))
             self.port_list = sorted(tmp)
+        else:
+            raise NotImplementedError("This port_spec is unknown: '{0}'".format(port_spec))
 
     def __eq__(self, val):
         if (self.protocol == val.protocol) and (self.port_list == val.port_list):
@@ -1116,7 +1139,9 @@ class L4Object(object):
         return False
 
     def __repr__(self):
-        return "<L4Object {0} {1}>".format(self.protocol, self.port_list)
+        crobj = CiscoRange()
+        crobj._list = self.port_list
+        return "<L4Object {0} ports: {1}>".format(self.protocol, crobj.compressed_str)
 
 
 class DNSResponse(object):
@@ -1589,17 +1614,27 @@ class CiscoRange(MutableSequence):
 >>>
         """
         retval = list()
-        prefix_str = self.line_prefix + self.slot_prefix
+        prefix_str = self.line_prefix.strip() + self.slot_prefix.strip()
+        prefix_str_len = len(prefix_str)
 
         # Build a list of integers (without prefix_str)
         input_str = list()
         for ii in self._list:
-            try:
-                unicode_ii = str(ii, "utf-8")  # Python2.7...
-            except:
+            # Removed try / except which is slower than sys.version_info
+            if sys.version_info < (3, 0, 0):
+                unicode_ii = unicode(str(ii))  # Python2.7...
+            else:
                 unicode_ii = str(ii)
-            ii = re.sub(r"^{0}(\d+)$".format(prefix_str), "\g<1>", unicode_ii)
-            input_str.append(int(ii))
+
+            # Removed this in version 1.5.27 because it's so slow...
+            #trailing_digits = re.sub(r"^{0}(\d+)$".format(prefix_str), "\g<1>", unicode_ii)
+
+            complete_len = len(unicode_ii)
+            # Assign ii to the trailing number after prefix_str...
+            #    this is much faster than regexp processing...
+            trailing_digits_len = complete_len - prefix_str_len
+            trailing_digits = unicode_ii[-1*trailing_digits_len:]
+            input_str.append(int(trailing_digits))
 
         if len(input_str) == 0:  # Special case, handle empty list
             return ""
