@@ -44,32 +44,44 @@ class JunosCfgLine(BaseCfgLine):
     :class:`~models_junos.JunosCfgLine` objects contain references to other 
     parent and child :class:`~models_junos.JunosCfgLine` objects.
 
-    .. note::
+    Notes
+    -----
+    Originally, :class:`~models_junos.JunosCfgLine` objects were only 
+    intended for advanced ciscoconfparse users.  As of ciscoconfparse 
+    version 0.9.10, *all users* are strongly encouraged to prefer the 
+    methods directly on :class:`~models_junos.JunosCfgLine` objects.  
+    Ultimately, if you write scripts which call methods on 
+    :class:`~models_junos.JunosCfgLine` objects, your scripts will be much 
+    more efficient than if you stick strictly to the classic 
+    :class:`~ciscoconfparse.CiscoConfParse` methods.
 
-       Originally, :class:`~models_junos.JunosCfgLine` objects were only 
-       intended for advanced ciscoconfparse users.  As of ciscoconfparse 
-       version 0.9.10, *all users* are strongly encouraged to prefer the 
-       methods directly on :class:`~models_junos.JunosCfgLine` objects.  
-       Ultimately, if you write scripts which call methods on 
-       :class:`~models_junos.JunosCfgLine` objects, your scripts will be much 
-       more efficient than if you stick strictly to the classic 
-       :class:`~ciscoconfparse.CiscoConfParse` methods.
+    Parameters
+    ----------
+    text : str
+        A string containing a text copy of the Junos configuration line.  :class:`~ciscoconfparse.CiscoConfParse` will automatically identify the parent and children (if any) when it parses the configuration. 
+     comment_delimiter : str
+         A string which is considered a comment for the configuration format.  Since this is for Cisco Junos-style configurations, it defaults to ``!``.
 
-    Args:
-        - text (str): A string containing a text copy of the Junos configuration line.  :class:`~ciscoconfparse.CiscoConfParse` will automatically identify the parent and children (if any) when it parses the configuration. 
-        - comment_delimiter (str): A string which is considered a comment for the configuration format.  Since this is for Cisco Junos-style configurations, it defaults to ``!``.
+    Attributes
+    ----------
+    text : str
+        A string containing the parsed Junos configuration statement
+    linenum : int
+        The line number of this configuration statement in the original config; default is -1 when first initialized.
+    parent : :class:`~models_junos.JunosCfgLine()`
+        The parent of this object; defaults to ``self``.
+    children : list
+        A list of ``JunosCfgLine()`` objects which are children of this object.
+    child_indent : int
+        An integer with the indentation of this object's children
+    indent : int
+        An integer with the indentation of this object's ``text`` oldest_ancestor (bool): A boolean indicating whether this is the oldest ancestor in a family
+    is_comment : bool
+        A boolean indicating whether this is a comment
 
-    Attributes:
-        - text     (str): A string containing the parsed Junos configuration statement
-        - linenum  (int): The line number of this configuration statement in the original config; default is -1 when first initialized.
-        - parent (:class:`~models_junos.JunosCfgLine()`): The parent of this object; defaults to ``self``.
-        - children (list): A list of ``JunosCfgLine()`` objects which are children of this object.
-        - child_indent (int): An integer with the indentation of this object's children
-        - indent (int): An integer with the indentation of this object's ``text`` oldest_ancestor (bool): A boolean indicating whether this is the oldest ancestor in a family
-        - is_comment (bool): A boolean indicating whether this is a comment
-
-    Returns:
-        - An instance of :class:`~models_junos.JunosCfgLine`.
+    Returns
+    -------
+    :class:`~models_junos.JunosCfgLine`
 
     """
 
@@ -90,10 +102,12 @@ class JunosCfgLine(BaseCfgLine):
         :class:`~models_junos.JunosCfgLine` is an interface; subinterfaces
         also return True.
 
-        Returns:
-            - bool.
+        Returns
+        -------
+        bool
 
-        This example illustrates use of the method.
+        Examples
+        --------
 
         .. code-block:: python
            :emphasize-lines: 17,20
